@@ -1,14 +1,15 @@
 package App::ProgUtils;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $DATE = '2015-09-17'; # DATE
+our $VERSION = '0.17'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
 our $_complete_program = sub {
-    require Complete::Util;
+    require Complete::File;
+    require Complete::Program;
     require List::MoreUtils;
 
     my %args = @_;
@@ -16,12 +17,12 @@ our $_complete_program = sub {
     my $word = $args{word} // '';
 
     # combine all executables (including dirs) and programs in PATH
-    my $c1 = Complete::Util::complete_file(
+    my $c1 = Complete::File::complete_file(
         word   => $word,
         filter => sub { -x $_[0] },
         #ci    => 1, # convenience, not yet supported by C::U
     );
-    my $c2 = Complete::Util::complete_program(
+    my $c2 = Complete::Program::complete_program(
         word => $word,
         ci   => 1, # convenience
     );
@@ -58,7 +59,7 @@ App::ProgUtils - Command line to manipulate programs in PATH
 
 =head1 VERSION
 
-This document describes version 0.16 of App::ProgUtils (from Perl distribution App-ProgUtils), released on 2015-09-03.
+This document describes version 0.17 of App::ProgUtils (from Perl distribution App-ProgUtils), released on 2015-09-17.
 
 =head1 SYNOPSIS
 
